import * as React from "react";
import { Animated, ViewProps } from "react-native";
import styled from "styled-components/native";
import {
    background,
    BackgroundProps,
    border,
    BorderProps,
    color,
    ColorProps,
    compose,
    flexbox,
    FlexboxProps,
    fontSize,
    FontSizeProps,
    layout,
    LayoutProps,
    position,
    PositionProps,
    shadow,
    ShadowProps,
    space,
    SpaceProps,
    textAlign,
    TextAlignProps
} from "styled-system";

export const systemProps = compose(
    space,
    layout,
    color,
    flexbox,
    background,
    border,
    position,
    shadow
);

export type StyledToastProps = SpaceProps &
    ColorProps &
    LayoutProps &
    FlexboxProps &
    BackgroundProps &
    BorderProps &
    PositionProps &
    ShadowProps & {
        elevation?: number
        accentColor?: string
    }

// const AnimatedTouchable = Animated.createAnimatedComponent(TouchableOpacity);

export const StyledToast = Animated.createAnimatedComponent(styled.TouchableOpacity<StyledToastProps>(systemProps));

StyledToast.defaultProps = {
    py: 2,
    mb: 4,
    flex: "1 1 auto",
    zIndex: 1000,
    width: "100%",
    bg: "background",
    borderWidth: "1px",
    borderRadius: "4px",
    alignItems: "center",
    flexDirection: "row",
    accentColor: "green",
    justifyContent: "center",
    borderColor: "black"
};

type AccentProps = ViewProps & SpaceProps & ColorProps & {

};

export const Accent: React.FC<AccentProps> = styled.View<ViewProps & SpaceProps & ColorProps>`
  ${color};
  top: 0;
  left: 0;
  bottom: 0;
  width: 4px;
  position: absolute;
  border-top-left-radius: 4px;
  border-bottom-left-radius: 4px;
`;

export type TextProps = SpaceProps & ColorProps & TextAlignProps & FontSizeProps

export const Heading = styled.Text<TextProps>`
  ${space};
  ${color};
  ${fontSize};
  ${textAlign};
  flex-wrap: wrap;
  font-weight: normal;
`;

Heading.defaultProps = {
    fontSize: 2,
    color: "text"
};

export const SubText = styled.Text<TextProps>`
  ${space};
  ${color};
  ${fontSize};
  ${textAlign};
  flex-wrap: wrap;
  font-weight: normal;
`;

SubText.defaultProps = {
    fontSize: 1,
    color: "text"
};

export const IconCont = styled.View<any>`
  ${space};
  align-items: center;
  justify-content: center;
`;

type CloseButtonContProps = {

}

export const CloseButtonCont: React.FC<CloseButtonContProps> = styled.TouchableOpacity<SpaceProps>`
  ${space};
  align-items: center;
  justify-content: center;
`;
