"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var React = _interopRequireWildcard(require("react"));

var _reactNative = require("react-native");

var _AlertDialog = _interopRequireDefault(require("./AlertDialog"));

var _Surface = _interopRequireDefault(require("../Surface"));

var _Dialog = require("../Dialog");

var _Button = _interopRequireDefault(require("../Button"));

var _styledComponents = require("styled-components");

var _Text = _interopRequireDefault(require("../Text"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const defaultProps = {
  mode: "message",
  translations: {
    confirmText: "Ok",
    cancelText: "Cancel"
  }
};

const AlertDialogWithRef = ({
  innerRef,
  children,
  mode,
  title,
  message,
  translations,
  dialogContentStyle,
  messageStyle,
  ...rest
}) => {
  const [visible, setVisible] = React.useState(false);
  const optionsRef = React.useRef({});
  const {
    colors
  } = React.useContext(_styledComponents.ThemeContext);
  React.useImperativeHandle(innerRef, () => ({
    open: options => {
      optionsRef.current = {
        onConfirm: options === null || options === void 0 ? void 0 : options.onConfirm,
        onCancel: options === null || options === void 0 ? void 0 : options.onCancel
      };
      setVisible(true);
    },
    close: () => {
      setVisible(false);
    }
  }));

  const _handleConfirm = () => {
    if (optionsRef && optionsRef.current && optionsRef.current.onConfirm) {
      optionsRef.current.onConfirm();
    }

    innerRef.current.close();
  };

  const _handleDismiss = () => {
    innerRef.current.close();
  };

  return /*#__PURE__*/React.createElement(_AlertDialog.default, _extends({
    animationType: "fade",
    visible: visible,
    onDismiss: _handleDismiss
  }, rest), /*#__PURE__*/React.createElement(_Surface.default, null, title ? /*#__PURE__*/React.createElement(_Dialog.DialogTitle, null, title) : null, /*#__PURE__*/React.createElement(_Dialog.DialogContent, {
    style: [styles.dialogContentStyle, dialogContentStyle]
  }, message ? /*#__PURE__*/React.createElement(_Text.default, {
    style: [mode === "error" && styles.errorMessage, mode === "error" && {
      color: colors.error
    }, messageStyle]
  }, message) : children), /*#__PURE__*/React.createElement(_Dialog.DialogActions, null, mode === "confirm" ? /*#__PURE__*/React.createElement(_Button.default, {
    onPress: _handleDismiss
  }, translations === null || translations === void 0 ? void 0 : translations.cancelText) : null, /*#__PURE__*/React.createElement(_Button.default, {
    onPress: _handleConfirm
  }, translations === null || translations === void 0 ? void 0 : translations.confirmText))));
};

AlertDialogWithRef.defaultProps = defaultProps;
var _default = AlertDialogWithRef;
exports.default = _default;

const styles = _reactNative.StyleSheet.create({
  dialogContentStyle: {
    paddingHorizontal: 16
  },
  errorMessage: {}
});
//# sourceMappingURL=AlertDialogWithRef.js.map