function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import * as React from "react";
import { StyleSheet, View } from "react-native";
import color from "color";
import TouchableRipple from "../TouchableRipple/TouchableRipple";
import { ThemeContext } from "styled-components";
import { SvgIcon } from "../Icon";
import MinusIcon from "@mdi/svg/svg/minus.svg";
import CheckIcon from "@mdi/svg/svg/check.svg";

/**
 * Checkboxes allow the selection of multiple options from a set.
 * This component follows platform guidelines for iOS, but can be used
 * on any platform.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img src="screenshots/checkbox-enabled.ios.png" />
 *     <figcaption>Enabled</figcaption>
 *   </figure>
 *   <figure>
 *     <img src="screenshots/checkbox-disabled.ios.png" />
 *     <figcaption>Disabled</figcaption>
 *   </figure>
 * </div>
 */
const CheckboxIOS = ({
  status,
  disabled,
  onPress,
  testID,
  ...rest
}) => {
  const theme = React.useContext(ThemeContext);
  const checked = status === "checked";
  const indeterminate = status === "indeterminate";
  const checkedColor = disabled ? theme.colors.disabled : rest.color || theme.colors.accent;
  let rippleColor;

  if (disabled) {
    rippleColor = color(theme.colors.text).alpha(0.16).rgb().string();
  } else {
    rippleColor = color(checkedColor).fade(0.32).rgb().string();
  }

  const icon = indeterminate ? MinusIcon : CheckIcon;
  return /*#__PURE__*/React.createElement(TouchableRipple, _extends({}, rest, {
    borderless: true,
    rippleColor: rippleColor,
    onPress: onPress,
    disabled: disabled // accessibilityTraits={disabled ? ['button', 'disabled'] : 'button'}
    // accessibilityComponentType="button"
    ,
    accessibilityRole: "checkbox",
    accessibilityState: {
      disabled,
      checked
    },
    accessibilityLiveRegion: "polite",
    style: styles.container,
    testID: testID
  }), /*#__PURE__*/React.createElement(View, {
    style: {
      opacity: indeterminate || checked ? 1 : 0
    }
  }, /*#__PURE__*/React.createElement(SvgIcon, {
    icon: icon,
    size: 24,
    color: checkedColor // direction="ltr"

  })));
};

CheckboxIOS.displayName = "Checkbox.IOS";
const styles = StyleSheet.create({
  container: {
    borderRadius: 18,
    padding: 6
  }
});
export default CheckboxIOS; // @component-docs ignore-next-line

const CheckboxIOSWithTheme = CheckboxIOS; // @component-docs ignore-next-line

export { CheckboxIOSWithTheme as CheckboxIOS };
//# sourceMappingURL=CheckboxIOS.js.map