import * as React from "react";
import { StyleProp, TextStyle, View, ViewStyle } from "react-native";
import type { $RemoveChildren } from "../types";
import { DefaultTheme } from "styled-components";
declare type Props = $RemoveChildren<typeof View> & {
    /**
     * Custom color for the text.
     */
    color?: string;
    /**
     * Text for the title.
     */
    title: React.ReactNode;
    /**
     * Style for the title.
     */
    titleStyle?: StyleProp<TextStyle>;
    /**
     * Reference for the title.
     */
    titleRef?: React.RefObject<Text>;
    /**
     * Text for the subtitle.
     */
    subtitle?: React.ReactNode;
    /**
     * Style for the subtitle.
     */
    subtitleStyle?: StyleProp<TextStyle>;
    /**
     * Function to execute on press.
     */
    onPress?: () => void;
    style?: StyleProp<ViewStyle>;
    /**
     * @optional
     */
    theme?: DefaultTheme;
};
/**
 * A component used to display a title and optional subtitle in an appbar.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/appbar-content.png" />
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import Appbar from 'react-native-simple-elements/components/Appbar';
 *
 * const MyComponent = () => (
 *     <Appbar.Header>
 *        <Appbar.Content title="Title" subtitle={'Subtitle'} />
 *     </Appbar.Header>
 * );
 *
 * export default MyComponent;
 * ```
 */
declare const AppbarContent: {
    ({ color: titleColor, subtitle, subtitleStyle, onPress, style, titleRef, titleStyle, title, ...rest }: Props): JSX.Element;
    displayName: string;
};
export default AppbarContent;
declare const AppbarContentWithTheme: {
    ({ color: titleColor, subtitle, subtitleStyle, onPress, style, titleRef, titleStyle, title, ...rest }: Props): JSX.Element;
    displayName: string;
};
export { AppbarContentWithTheme as AppbarContent };
