import * as React from "react";
import { ViewStyle, StyleProp } from "react-native";
declare type Props = {
    /**
     * Icon to show.
     */
    icon: React.ReactElement;
    /**
     * Color for the icon.
     */
    color?: string;
    style?: StyleProp<ViewStyle>;
};
/**
 * A component to show an icon in a list item.
 *
 * <div class="screenshots">
 *   <figure>
 *     <img class="medium" src="screenshots/list-icon.png" />
 *   </figure>
 * </div>
 *
 * ## Usage
 * ```js
 * import * as React from 'react';
 * import { ListIcon } from 'react-native-simple-elements/components/List';
 * import * as Colors from "react-native-simple-elements/components/theme/colors";
 *
 * const MyComponent = () => (
 *   <>
 *     <List.Icon color={Colors.blue500} icon="folder" />
 *     <List.Icon color={Colors.blue500} icon="equal" />
 *     <List.Icon color={Colors.blue500} icon="calendar" />
 *   </>
 * );
 *
 * export default MyComponent;
 * ```
 */
declare const ListIcon: {
    ({ icon, color: iconColor, style }: Props): JSX.Element;
    displayName: string;
};
export default ListIcon;
